@@ -195,35 +195,51 @@ class Clone(Function, Module):
 
 
 class SlidingWindowView(Function, Module):
-    """
-    Smart Vectorized Sliding Window View with AutoDiff Support and
-    sliding view buffer to avoid unnecessary memory allocation.
-    """
+    """Compact sliding window view using as_strided for all cases."""
     def __init__(self, window_shape: Sequence[int],
                  axes: Union[int, Tuple[int, ...]] = (2, 3),
                  strides: Union[int, Tuple[int, ...]] = (1, 1)):
         Function.__init__(self)
         Module.__init__(self)
         self.axes = axes if isinstance(axes, tuple) else (axes,)
-        self.strides = strides if isinstance(strides, tuple) else \
-                       tuple(strides for _ in range(len(self.axes)))
-        self.window_shape = window_shape if isinstance(window_shape, tuple) else \
-                           tuple(window_shape for _ in range(len(axes)))
+        self.strides = strides if isinstance(strides, tuple) else tuple(strides for _ in range(len(self.axes)))
+        self.window_shape = window_shape if isinstance(window_shape, tuple) else tuple(window_shape for _ in range(len(self.axes)))
+    
     def forward(self, A: xp.ndarray) -> xp.ndarray:
-        slices = [slice(None)] * A.ndim
-        for ax, stride in zip(self.axes, self.strides):
-            slices[ax] = slice(None, None, stride)
-        self.slices = tuple(slices)
-        return xp.lib.stride_tricks.sliding_window_view(
-            A, self.window_shape, self.axes)[self.slices]
+        # Calculate output shape
+        out_shape = list(A.shape)
+        for i, (ax, ws, st) in enumerate(zip(self.axes, self.window_shape, self.strides)):
+            out_shape[ax] = (A.shape[ax] - ws) // st + 1
+        out_shape.extend(self.window_shape)
+        
+        # Calculate strides
+        out_strides = list(A.strides)
+        for ax, st in zip(self.axes, self.strides):
+            out_strides[ax] *= st
+        out_strides.extend([A.strides[ax] for ax in self.axes])
+        
+        return xp.lib.stride_tricks.as_strided(A, shape=tuple(out_shape), strides=tuple(out_strides))
+    
     def backward(self, grad_output: xp.ndarray) -> xp.ndarray:
         A = self.parent_tensors[0]
+        if not A.requires_grad:
+            return None
+        
         grad_buffer = xp.zeros(A.shape, dtype=grad_output.dtype)
         kwargs = {"writeable": True} if xp is np else {}
-        grad_view = xp.lib.stride_tricks.sliding_window_view(
-            grad_buffer, self.window_shape, self.axes, **kwargs
-        )[self.slices]
-        # Accumulate gradients using cached view
+        
+        # Create gradient view with same logic as forward
+        out_shape = list(grad_buffer.shape)
+        for ax, ws, st in zip(self.axes, self.window_shape, self.strides):
+            out_shape[ax] = (grad_buffer.shape[ax] - ws) // st + 1
+        out_shape.extend(self.window_shape)
+        
+        out_strides = list(grad_buffer.strides)
+        for ax, st in zip(self.axes, self.strides):
+            out_strides[ax] *= st
+        out_strides.extend([grad_buffer.strides[ax] for ax in self.axes])
+        
+        grad_view = xp.lib.stride_tricks.as_strided(grad_buffer, shape=tuple(out_shape), strides=tuple(out_strides), **kwargs)
         grad_view += grad_output
         return grad_buffer
     
